==> kdenetwork-3.1.3.tar.bz2: kdenetwork-3.1.3/kget/dlgLimits.h <==
/***************************************************************************
*                                dlgLimits.h
*                             -------------------
*
*    Revision     : $Id: dlgLimits.h,v 1.6 2002/11/01 03:18:21 pfeiffer Exp $
*    begin        : Tue Jan 29 2002
*    copyright    : (C) 2002 by Patrick Charbonnier
*                 : Based On Caitoo v.0.7.3 (c) 1998 - 2000, Matej Koss
*    email        : pch@freeshell.org
*
****************************************************************************/

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 ***************************************************************************/


#ifndef _DLGLIMITS_H
#define _DLGLIMITS_H

#include <qgroupbox.h>

class QLabel;
class KIntNumInput;

class DlgLimits:public QGroupBox
{

Q_OBJECT public:

    DlgLimits(QWidget * parent);
    ~DlgLimits()
    {}
    void applyData();
    void setData();

private:

    // opened connections
    QLabel * lb_maxnum;
    KIntNumInput *le_maxnum;

    // minimum bandwidth
    QLabel *lb_minband;
    KIntNumInput *le_minband;

    // maximum bandwidth
    QLabel *lb_maxband;
    KIntNumInput *le_maxband;

};

#endif                          // _DLGLIMITS_H

==> kdenetwork-3.4.2.tar.bz2: kdenetwork-3.4.2/kget/dlgLimits.h <==
/***************************************************************************
*                                dlgLimits.h
*                             -------------------
*
*    Revision     : $Id: dlgLimits.h 252202 2003-09-18 18:46:39Z nhasan $
*    begin        : Tue Jan 29 2002
*    copyright    : (C) 2002 by Patrick Charbonnier
*                 : Based On Caitoo v.0.7.3 (c) 1998 - 2000, Matej Koss
*    email        : pch@freeshell.org
*
****************************************************************************/

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 ***************************************************************************/


#ifndef _DLGLIMITS_H
#define _DLGLIMITS_H

#include "dlglimitsbase.h"

class DlgLimits : public DlgLimitsBase
{

Q_OBJECT public:

    DlgLimits(QWidget * parent);
    ~DlgLimits() {}
    void applyData();
    void setData();

signals:
    void configChanged();

protected slots:
    void slotChanged();

};

#endif                          // _DLGLIMITS_H
